"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const fs = require("fs");
const os = require("os");
const vscode = require("vscode");
const vscode_languageclient_1 = require("vscode-languageclient");
let client;
function activate(context) {
    var _a;
    const ensime_java = vscode.workspace.getConfiguration().get('ensime.java') || "java";
    const ensime_javaargs = vscode.workspace.getConfiguration().get('ensime.javaargs') || "";
    const ensime_lspjar = ((_a = vscode.workspace.getConfiguration().get('ensime.lspjar')) === null || _a === void 0 ? void 0 : _a.replace("~", os.homedir)) || "";
    const runArgs = ensime_javaargs.split(" ").concat(["-jar", ensime_lspjar]);
    if (!fs.existsSync(ensime_lspjar)) {
        vscode.window.showErrorMessage(`ENSIME: not available (${ensime_lspjar}). Visit https://ensime.github.io/ to download and install.`);
    }
    const serverOptions = {
        run: { command: ensime_java, transport: vscode_languageclient_1.TransportKind.stdio, args: runArgs },
        // debug is hacked, we don't actually do anything differently...
        debug: { command: ensime_java, transport: vscode_languageclient_1.TransportKind.stdio, args: runArgs },
    };
    const clientOptions = {
        documentSelector: [
            { scheme: 'file', language: 'scala' },
        ],
    };
    client = new vscode_languageclient_1.LanguageClient('ensime-lsp', 'ENSIME Language Server', serverOptions, clientOptions);
    vscode.commands.registerTextEditorCommand('ensime.import', (editor, edit, args) => {
        client.sendRequest(vscode_languageclient_1.ExecuteCommandRequest.type, {
            command: 'ensime.import',
            arguments: [editor.document.uri.toString(), editor.selection.active.line, editor.selection.active.character]
        });
    });
    client.start();
}
exports.activate = activate;
function deactivate() {
    if (!client) {
        return undefined;
    }
    return client.stop();
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map